@@ -36,8 +36,8 @@ class XRandRScreen : public QObject
     Q_OBJECT
 
 public:
-    explicit XRandRScreen(XRandRConfig *config = 0);
-    virtual ~XRandRScreen();
+    explicit XRandRScreen(XRandRConfig *config = nullptr);
+    ~XRandRScreen() override;
 
     KScreen::ScreenPtr toKScreenScreen() const;
     void updateKScreenScreen(KScreen::ScreenPtr &screen) const;
